<?

$version = "3.7C";

################################################################################
# SENSOR MANAGEMENT TOOLS - AANVAL INTRUSION DETECTION CONSOLE
################################################################################

// Includes
if (!include("conf.php")) {
	echo "ERROR - Could not access conf.php. Ensure it is in the local directory and / or 'open_basedir' is disabled in your php.ini\n\n";
}

// Sets
ini_set("memory_limit", "64M");
ini_set("error_reporting", "E_ALL & ~E_NOTICE");

// Launch
go();

function go() {
	global $version, $protocol, $consoleHost, $consoleHostPath, $id;

    echo "Aanval - Sensor Management Tools - v.$version\n---\n";

    if ($protocol == "HTTPS" || $protocol == "https") {
	    echo "* Using HTTPS > If you experience problems, please try without SSL\n";
    }
    
    echo "* Connections will use: $protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php\n---\nSensor ID: $id\n---\n\n";

    if (!$protocol) {
    	echo "ERROR - Protocol variable in configuration file is not set.";
    	exit;
    }
    if (!$consoleHost) {
    	echo "ERROR - Console Host variable in configuration file is not set.";
    	exit;
    }
    if (!$consoleHostPath) {
    	echo "ERROR - Console Host Path variable in configuration file is not set.";
    	exit;
    }
    if (!$id) {
    	echo "ERROR - SMT ID variable in configuration file is not set.";
    	exit;
    }
    
	$res = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");

	if ($res) {
		processMessage($res);
	} else {
		echo "ERROR - Connection Failed\n* Check host, host path and id settings within your conf.php\n";
	}
	
	echo "\n---\nDone.\n\n";
}

function processMessage($res) {
	global $protocol, $consoleHost, $consoleHostPath, $id, $confSnort, $rulesSnort, $sensorDataPath, $cmdSnortStatus, $cmdSnortStart, $cmdSnortStop, $cmdUptime;
	
	$res = trim($res);
	
	if (!$res) {
		$rmsg = "( ERROR: NULL message received. Check console webserver logs to resolve. )";	
	} else {
		$rmsg = "( 0 is okay )";
	}
	
	echo "SMT: Aanval Message Result\t[ $res ]\t$rmsg\n";
	
	if ($res == "SNORTRESTART") {
		
		$tmp = exec("$cmdSnortStop", $data);
        $tmp = exec("$cmdSnortStart", $data);
		$code = 1;
		
	} else if ($res == "SNORTSTOP") {
        
		$tmp = exec("$cmdSnortStop", $data);
		$code = 2;
		
	} else if ($res == "SNORTSTART") {
        
		$tmp = exec("$cmdSnortStart", $data);
		$code = 3;
		
    } else if ($res == "UPTIME") {

    	$tmp = exec($cmdUptime, $return);
		$data = urlBase64_encode($return[0]);
		$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&uptime=$data");
        $code = 4;
        
    } else if ($res == "SNORTCONFGET") {

    	$confData = file_get_contents($confSnort);
    	$postData = "id=$id&confsend=1&file=" . basename($confSnort) . "&data=" . urlBase64_encode($confData);
		sendToHost($consoleHost, "$consoleHostPath/poll/sensor_poll.php", $postData, 0);		
		$code = 5;
		
    } else if ($res == "SNORTCONFSEND") {
        
		$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&confget=1");
		if (!empty($tmp)) {
	        // Open File For Write
	        if ($fp = @fopen($confSnort, "w")) {
	        	fputs ($fp, urlBase64_decode($tmp));
	            fclose($fp);
	        }  
		}
		$code = 6;
		
    } else if ($res == "SNORTRULESGET") {

        if (!$rules = @dir("$rulesSnort")) {
            echo "ERROR - Could not locate rules (Check to ensure directories are correct in conf.php)";
            exit;
        }
        
        while ($fileTmp = $rules->read()) {
            if ($fileTmp != "." && $fileTmp != ".." && $fileTmp != "snort.conf") {
                $files[] = $fileTmp;
            }
        }
        		
		foreach($files as $file) {
	    	$ruleData = file_get_contents("$rulesSnort/$file");
	    	$postData = "id=$id&rulessend=1&file=$file&data=" . urlBase64_encode($ruleData);
			sendToHost($consoleHost, "$consoleHostPath/poll/sensor_poll.php", $postData, 0);			
			$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");
			unset($tmp);
		}
    	$code = 7;
                		
    } else if ($res == "SNORTRULESSEND") {

		$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&rulesget=1");

        if ($tmp) {
    		$ruleList = explode("\n", $tmp);
		}

		foreach($ruleList as $rule) {
			$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&ruleget=1&rule=$rule");
			if (!empty($tmp)) {
		        // Open File For Write
		        if ($fp = @fopen("$rulesSnort/$rule", "w")) {
		        	fputs ($fp, urlBase64_decode($tmp));
		            fclose($fp);
		        }  
			}	
			$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");
			unset($tmp);
		}
        $code = 8;
        
    } else if ($res == "SENSORUPDATE") {
    	
		$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&update=1");
        if ($tmp) {
	        if ($fp = @fopen("$sensorDataPath/smt.php.NEW", "w")) {
	        	fputs ($fp, urlBase64_decode($tmp));
	            fclose($fp);
	        } 
        }
		$code = 9;        
        
    } else if ($res == "SNORTSTATUS") {
    	
		$tmp = exec("$cmdSnortStatus", $data);
		if ($data) {
			echo "SMT: Snort Process Found\n";
			$status = 1;
		} else {
			echo "SMT: Snort Process NOT Found\n";
			$status = 0;
		}
		$tmp = file_get_contents("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&snortstatus=1&data=$status");
        $code = 10;

	} else {
		$code = 0;
    }
	
	echo "SMT: Aanval Internal Code\t[ $code ]\n";
	
}

function sendToHost($host, $path, $data, $useragent = 0) {
	global $protocol;
	
	$method = "POST";
	
	if ($protocol == "HTTPS" || $protocol == "https") {
		$port = 443;
	} else {
		$port = 80;
	}
	
    $fp = fsockopen($host, $port);

    fputs($fp, "$method $path HTTP/1.1\r\n");
    fputs($fp, "Host: $host\r\n");
    fputs($fp,"Content-type: application/x-www-form-urlencoded\r\n");
    fputs($fp, "Content-length: " . strlen($data) . "\r\n");
    if ($useragent) {
        fputs($fp, "User-Agent: MSIE\r\n");
    }
    fputs($fp, "Connection: close\r\n\r\n");
    if ($method == 'POST') {
        fputs($fp, $data);
    }

    while (!feof($fp)) {
        $buf .= fgets($fp,128);
    }
    fclose($fp);
    
    return $buf;
}

function urlBase64_decode($string) {
  
	$string = str_replace( '-', '+', $string );
	$string = str_replace( '_', '/', $string );
	$string = str_replace( '.', '=', $string );
	
	return base64_decode($string);
}

function urlBase64_encode($string) {

	$string = base64_encode($string);
	$string = str_replace( '+', '-', $string );
	$string = str_replace( '/', '_', $string );
	$string = str_replace( '=', '.', $string );
	
	return $string;
}

?>